==> genometools-1.3.3.tar.gz: genometools-1.3.3/src/extended/merge_feature_stream.c <==
/*
  Copyright (c) 2006-2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include "core/assert_api.h"
#include "extended/merge_feature_stream.h"
#include "extended/merge_feature_visitor.h"
#include "extended/node_stream_rep.h"

struct GtMergeFeatureStream {
  const GtNodeStream parent_instance;
  GtNodeStream *in_stream;
  GtNodeVisitor *mergefeat_visitor;
};

#define gt_merge_feature_stream_cast(GS)\
        gt_node_stream_cast(gt_merge_feature_stream_class(), GS)

static int merge_feature_stream_next(GtNodeStream *ns, GtGenomeNode **gn,
                                     GtError *err)
{
  GtMergeFeatureStream *mfs;
  int had_err;
  gt_error_check(err);
  mfs = gt_merge_feature_stream_cast(ns);
  had_err = gt_node_stream_next(mfs->in_stream, gn, err);
  if (!had_err && *gn)
    had_err = gt_genome_node_accept(*gn, mfs->mergefeat_visitor, err);
  return had_err;
}

static void merge_feature_stream_free(GtNodeStream *ns)
{
  GtMergeFeatureStream *mfs = gt_merge_feature_stream_cast(ns);
  gt_node_visitor_delete(mfs->mergefeat_visitor);
}

const GtNodeStreamClass* gt_merge_feature_stream_class(void)
{
  static const GtNodeStreamClass *nsc = NULL;
  if (!nsc) {
    nsc = gt_node_stream_class_new(sizeof (GtMergeFeatureStream),
                                   merge_feature_stream_free,
                                   merge_feature_stream_next);
  }
  return nsc;
}

GtNodeStream* gt_merge_feature_stream_new(GtNodeStream *in_stream)
{
  GtNodeStream *ns = gt_node_stream_create(gt_merge_feature_stream_class(),
                                           false);
  GtMergeFeatureStream*mfs = gt_merge_feature_stream_cast(ns);
  mfs->in_stream = in_stream;
  mfs->mergefeat_visitor = gt_merge_feature_visitor_new();
  return ns;
}

==> genometools-1.3.4.tar.gz: genometools-1.3.4/src/extended/merge_feature_stream.c <==
/*
  Copyright (c) 2006-2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg

  Permission to use, copy, modify, and distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#include "core/assert_api.h"
#include "extended/merge_feature_stream.h"
#include "extended/merge_feature_visitor.h"
#include "extended/node_stream_api.h"

struct GtMergeFeatureStream {
  const GtNodeStream parent_instance;
  GtNodeStream *in_stream;
  GtNodeVisitor *mergefeat_visitor;
};

#define gt_merge_feature_stream_cast(GS)\
        gt_node_stream_cast(gt_merge_feature_stream_class(), GS)

static int merge_feature_stream_next(GtNodeStream *ns, GtGenomeNode **gn,
                                     GtError *err)
{
  GtMergeFeatureStream *mfs;
  int had_err;
  gt_error_check(err);
  mfs = gt_merge_feature_stream_cast(ns);
  had_err = gt_node_stream_next(mfs->in_stream, gn, err);
  if (!had_err && *gn)
    had_err = gt_genome_node_accept(*gn, mfs->mergefeat_visitor, err);
  return had_err;
}

static void merge_feature_stream_free(GtNodeStream *ns)
{
  GtMergeFeatureStream *mfs = gt_merge_feature_stream_cast(ns);
  gt_node_visitor_delete(mfs->mergefeat_visitor);
}

const GtNodeStreamClass* gt_merge_feature_stream_class(void)
{
  static const GtNodeStreamClass *nsc = NULL;
  if (!nsc) {
    nsc = gt_node_stream_class_new(sizeof (GtMergeFeatureStream),
                                   merge_feature_stream_free,
                                   merge_feature_stream_next);
  }
  return nsc;
}

GtNodeStream* gt_merge_feature_stream_new(GtNodeStream *in_stream)
{
  GtNodeStream *ns = gt_node_stream_create(gt_merge_feature_stream_class(),
                                           false);
  GtMergeFeatureStream*mfs = gt_merge_feature_stream_cast(ns);
  mfs->in_stream = in_stream;
  mfs->mergefeat_visitor = gt_merge_feature_visitor_new();
  return ns;
}
